@@ -143,15 +143,15 @@ class LibraryExperiment(object):
 
         """
         bowtie_res = pd.read_csv(self.bowtie_res, 
-                               names=["id_in_pool","pool","coord","orientation","barcode"],
-                               dtype= {"id_in_pool": str, "pool": str, "coord":str, "orientation":str, "barcode":str})
+                               names=["id_in_pool","pool","coord","orientation","barcode", "ref"],
+                               dtype= {"id_in_pool": str, "pool": str, "coord":str, "orientation":str, "barcode":str, "ref":str})
             
         bowtie_res["barcode"] = bowtie_res["barcode"].astype(str)
     
         # barcodes that were not found are treated the same (can't distinguish between them)
         # concat orientation, coordinate and barcode to create unique ids
-        bowtie_res["unique_id"] = bowtie_res["orientation"].astype(str) + \
-            bowtie_res["coord"].astype(str)   + bowtie_res["barcode"].astype(str)
+        bowtie_res["unique_id"] = bowtie_res["orientation"].astype(str) +";" +\
+            bowtie_res["coord"].astype(str)+ ";"   + bowtie_res["barcode"].astype(str)+ ";"  + bowtie_res["ref"].astype(str)
         
         encoded_ids = get_hash_ids(bowtie_res["unique_id"])
         
